require "import"
import "android.content.Intent"
import "android.net.Uri"
import "android.widget.*"
import "android.view.*"
import "android.os.Vibrator"
import "android.content.Context"
import "com.androlua.LuaDialog"

-- Obtener el servicio de vibración
local vibrator = service.getSystemService(Context.VIBRATOR_SERVICE)

-- Título de la interfaz
local titleText = "Grupo de Amistad Tecnológica"

-- Mensaje de bienvenida
local welcomeMessageText = [[
Grupo de Amistad Tecnológica:
- Se trata de un grupo de personas interesadas en la tecnología 💻.
- Se organizan actividades relacionadas con la tecnología 📱, como talleres y conferencias 🎓.
- Los miembros comparten conocimientos y experiencias en el campo tecnológico 🤓.
- El grupo fomenta la colaboración y el apoyo mutuo entre sus miembros 🤝.
- Se crean relaciones de amistad y networking en el ámbito tecnológico 🌐.
]]

-- Enlaces de los grupos
local telegramChannel = "https://t.me/+W19fc3Vrwis3ZDBh"
local telegramGroup = "https://t.me/+1GpS_2JW5AY0MGIx"
local whatsappCommunity = "https://chat.whatsapp.com/FRKShwdYxpeEZJsXWgylnv"

-- Crear el diseño de la interfaz
local dialogLayout = {
    LinearLayout;
    orientation = "vertical";
    layout_width = "match_parent";
    layout_height = "wrap_content";
    padding = "16dp";
    gravity = "center";

    -- Botón para cerrar
    {
        Button;
        id = "closeButton";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        layout_gravity = "center";
        text = "Cerrar";
    };

    -- Mensaje informativo
    {
        TextView;
        id = "welcomeMessage";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        layout_gravity = "center";
        textSize = "16sp";
        text = welcomeMessageText;
    };

    -- Botones de enlaces
    {
        Button;
        id = "telegramChannelButton";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        layout_gravity = "center";
        text = "Canal de Telegram";
    };

    {
        Button;
        id = "telegramGroupButton";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        layout_gravity = "center";
        text = "Grupo de Telegram";
    };

    {
        Button;
        id = "whatsappCommunityButton";
        layout_width = "wrap_content";
        layout_height = "wrap_content";
        layout_gravity = "center";
        text = "Comunidad de WhatsApp";
    };
}

-- Crear el cuadro de diálogo
local dlg = LuaDialog(service)
dlg.setTitle(titleText)
dlg.setView(loadlayout(dialogLayout))
dlg.setCanceledOnTouchOutside(false)

-- Función para abrir enlaces con vibración
local function openLink(url)
    if vibrator then
        vibrator.vibrate(100) -- Vibración de 100ms
    end
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
    intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
    service.startActivity(intent)
    dlg.dismiss()
end

-- Asignar funciones a los botones
telegramChannelButton.onClick = function()
    openLink(telegramChannel)
end

telegramGroupButton.onClick = function()
    openLink(telegramGroup)
end

whatsappCommunityButton.onClick = function()
    openLink(whatsappCommunity)
end

closeButton.onClick = function()
    if vibrator then
        vibrator.vibrate(100) -- Vibración al cerrar
    end
    dlg.dismiss()
end

-- Mostrar la interfaz
dlg.show()
